#
# spec file for package python-pywlroots
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%bcond_without test
Name:           python-pywlroots
Version:        0.17.0
Release:        1.3
Summary:        Python binding to the wlroots library using cffi
License:        NCSA
Group:          Development/Languages/Python
URL:            https://github.com/flacjacket/pywlroots
Source0:        https://files.pythonhosted.org/packages/source/p/pywlroots/pywlroots-%{version}.tar.gz
Source1:        python-pywlroots-rpmlintrc
# Patch0:         fix-include-paths.patch
BuildRequires:  %{python_module cffi}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module distutils-extra}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pywayland >= 0.4.14}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module xkbcommon >= 0.2}
BuildRequires:  %{pythons}
BuildRequires:  fdupes
BuildRequires:  libdrm >= 2.4.113
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(wlroots) >= 0.17.0
# For future possible versions
BuildConflicts: pkgconfig(wlroots) >= 0.18.0
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xwayland)
Requires:       python-pywayland
Requires:       python-xkbcommon
%python_subpackages

%description
Python binding to the wlroots library using cffi.

%prep
%autosetup -n pywlroots-%{version}

%build
export CFLAGS="%optflags $(pkg-config --cflags wayland-client xkbcommon pixman-1 libinput libdrm)"
%python_exec wlroots/ffi_build.py
%pyproject_wheel

%install
export CFLAGS="%optflags $(pkg-config --cflags wayland-client xkbcommon pixman-1 libinput libdrm)"
%python_exec wlroots/ffi_build.py
%pyproject_install

%python_expand %fdupes %{buildroot}%{$python_sitearch}

%if %{with test}
%check
export CFLAGS="%optflags $(pkg-config --cflags wayland-client xkbcommon pixman-1 libinput libdrm)"
%pytest -vv
%endif

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/*wlroots*/

%changelog
* Sat May 25 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Use autosetup to replace deprecated patch
* Sat May 25 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.17.0
  * Support for wlroots 0.17.x * Breaking change Rename all declarations of XdgTopLevel.* to XdgToplevel.*
  * Fixed Seat.touch_point_clear_focus: The method took too many arguments which were not aligned to the wlroots counterpart and lead to a runtime error.
  * Fixed Renderer.autocreate return value check. This also replaces some of the exceptions from render_texture and render_texture_with_matrix with boolean return values.
  * Fixed: XdgTopLevel.parent always returnd a parent even if the parent is NULL.
  * Fixed return type of Seat.touch_notify_down: Returns an integer now (the
  * serial identifier)
  * Added support for wlr_switch
  * Added Seat.touch_send_* methods
  * Added TouchPoint class
  * Real support for wlr_touch. The previous implementations were not usable.
  * Added support for the Single-pixel buffer protocol.
  * Added (experimental) support for the Session lock V1 protocol
  * Added Output.enable_adaptive_sync(bool)
  * Added Cursor.detach_input_device()
  * Added Backend.is_multi property which indicates if the backend represents a multi-backend
  * Added Pointer.data property
  * Added support for wlr_touch
  * Added support for OutputState which simplifies the configuration of Output
  * Removed Seat.has_grab(): Use the explicit methods like Seat.keyboard_has_grab(), Seat.pointer_has_grab() or Seat.touch_has_grab()
  * Renamed the touch events to maintain a consistent naming scheme: TouchEventUp -> TouchUpEvent, TouchEventDown -> TouchDownEvent, TouchEventMotion -> TouchMotionEvent, TouchEventCancel -> TouchCancelEvent
  * The following methods don't throw a RuntimeError anymore, but return a boolean value like the wlroots API: Backend.start(), Output.commit(), and SceneOutput.commit()
  * Deprecated Seat.set_keyboard(): Use the Seat.keyboard property
  * Seat.keyboard (and Seat.set_keyboard()) accepts None as valid value.
* Thu May 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Adjust commented out patch apply command to ensure whoever
  applies it will use the non-deprecated format.
* Sun Dec 17 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Limit wlroots version to 0.16.x and before 0.17.x
* Sat Oct 21 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Use %%{?sle15_python_module_pythons}
* Thu Oct 19 2023 Soc Virnyl Estela <contact@uncomfyhalomacro.pl>
- Update to version 0.16.6:
  * add missing include
  * add support for python 3.12
* Tue Oct  3 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.16.5:
  * update wlroots url in README
  * expose wlr_keyboard_notify_modifiers function
  * migrated to use PEP517 compatible release process
* Sat Apr 22 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.16.4:
  * add idle_notify_v1 protocol
  * add helpers for XDG activation v1 protocol
  * add helpers for presentation time protocol
  * add helpers for mapping input devices to outputs
  * enable xwayland feature for wlroots build setup when making a release
  * minor keyboard handling improvements
* Tue Feb 21 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.16.0:
  * Added support for wlroots 0.16.x
* Sun Feb 12 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove fix-include-paths.patch
* Sat Feb  4 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Use pkg-config and %%optflags for CFLAGS.
* Mon Dec 12 2022 Michael Vetter <mvetter@suse.com>
- Fix build: pick up a compatible verison of wlroots boo#1206305
* Sun Dec 11 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.15.24:
  * Drag.icon can also return None if clients don't provide icons to render
  * Drag.icon can also return None if clients don't provide icons to render
  * Add handlers for wlr_pointer_gestures_v1
* Mon Nov 21 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove libwlroots10. Not needed since library is provided already
  from wlroots-devel with pkg-config.
* Sat Sep 24 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add libdrm in BuildRequires for the spec
* Sat Sep 24 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Bump version to 0.15.22:
  * Add method to XCursorManager for wlr_xcursor_manager_load
  * Bump libdrm version to 2.4.113 in CI to fix build agaist wlroots master
* Sat Aug 20 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.15.19:
  * [bindgen] wlr_viewporter
  * Bump version of wayland used for testing
  * Skip header check for auto-generated line
  * Wrap input inhibitor active client in pywayland client
  * Update pywayland minimum version
* Tue Jul 19 2022 John Vandenberg <jayvdb@gmail.com>
- Add runtime dependencies python-pywayland & python-xkbcommon
* Wed Jul 13 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Rename to python-pywlroots. Enables builds for all available python flavors.
* Thu Jul  7 2022 Soc Virnyl S. Estela <socvirnyl.estela@gmail.com>
- Initial spec for python-pywlroots version 0.15.18
- add python-pywlroots-rpmlintrc:
  * addFilter("devel-file-in-non-devel-package") since it is actually
    part of the library
- add fix-include-paths.patch
